import sequelize from '../../new_dao/db/sequelize'
import { generateKeyPair } from 'crypto';
const fs = require('fs');
const path = require('path');
const database = 'pacsonline_3';
export async function test(ctx) {
  const fileUri = path.join(__dirname, '../../test_dao', 'table.json');
  const sql = `SELECT table_name, table_comment FROM information_schema.TABLES WHERE table_schema = '${database}';`;
  const res = await sequelize.query(sql);
  console.log('res', res)
  const tables = getTables(res[0]);
  const jsons = [];
  for (let i = 0; i < tables.length; i++) {
    const table = await getTableDetail(tables[i]);
    jsons.push(table);
  }
  const dbs = [];
  for (let i = 0; i < jsons.length; i++) {
    const json = jsons[i];
    const db = await generateDb(json);
    dbs.push(db);
  }
  generateIndex(dbs);

  fs.writeFileSync(fileUri, JSON.stringify(jsons))
    // console.log(array);
    // select column_name, is_nullable, data_type, column_type, column_key, column_comment from information_schema.COLUMNS where table_name = 'studies' and table_schema = 'pacsonline'
    // show create table studies
    // show index from studies
    // console.log(res)
}

function generateIndex(dbs) {
  console.log(dbs)
  const fileUri = path.join(__dirname, '../../test_dao', 'index.js');
  const importStr = dbs.reduce((pre, db) => pre + `import ${db.namespace} from './${db.name}'\r\n`, '');
  const exportStr = dbs.reduce((pre, db) => pre + `  ${db.namespace},\r\n`, '\r\n');
  fs.writeFileSync(fileUri, importStr + 'export {' + exportStr + '}');


}

function generateDb(json) {
  const name = json.name;
  // let createdAt = false;
  // let updatedAt = false;

  let createdAt = "'createdAt'";
  let updatedAt = "'updatedAt'";
  const comment = json.comment;
  const buildSql = json.buildSql;
  // const columns = json.columns;
  const columns = [];
  for (let i = 0; i < json.columns.length; i++) {
    let single = json.columns[i];
    let column = {};
    if (single.is_nullable === 'NO') {
      column.allowNull = false;
    } else {
      column.allowNull = true;
    }
    column.name = single.name;
    column.primaryKey = single.key === 'PRI';
    column.comment = single.comment;
    column.defaultValue = single.default;
    if (column.primaryKey && column.allowNull) {
      column.allowNull = false;
    }
    // if (!column.allowNull && column.defaultValue === null) {
    //   column.defaultValue = '';
    // }
    column.type = single.column_type.replace('json', 'JSON').replace('varchar', 'STRING').replace('char', 'CHAR').replace('bigint', 'BIGINT').replace('tinyint', 'TINYINT').replace('smallint', 'SMALLINT').replace('int', 'INTEGER').replace('text', 'TEXT').replace('datetime', 'DATE').replace('date', 'DATE');
    if (column.name === 'createdAt') {
      createdAt = "'createdAt'";
    } else if (column.name === 'updatedAt') {
      updatedAt = "'updatedAt'";
    } else {
      columns.push(column);
    }
  }
  const namespace = name.replace(name[0], name[0].toUpperCase());
  const columnsStr = columns.reduce((pre, column) => pre + `  ${column.name}: { type: Sequelize.${column.type}, allowNull: ${column.allowNull}, primaryKey: ${column.primaryKey}${column.defaultValue === null ? '': ', defaultValue: ' + (typeof column.defaultValue === 'string' ? "'" + column.defaultValue + "'": column.defaultValue)}, comment: '${column.comment}'},\r\n`, '\r\n');
  const sql = `const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const ${namespace} = sequelize.define('${name}', {${columnsStr}},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: ${createdAt},
  updatedAt: ${updatedAt},
});

${namespace}.sync({ force: false }).then(function() {});

export default ${namespace};
/**
 create sql
 ${buildSql}
*/
`;
  console.log('name', name)
  fs.writeFileSync(path.join(__dirname, '../../test_dao', `${name}.js`), sql)
  return {
    namespace,
    name,
    comment,
    buildSql,
    columns
  };
  // const name = json.name;
  // const is_nullable = json.is_nullable;
  // const data_type = json.data_type;
  // const column_key = json.column_key;
  // const comment = json.comment;
  // const indexs
}

function getTables(res) {
  const tables = [];
  for (let i = 0; i < res.length; i++) {
    tables.push({ name: res[i].table_name, comment: res[i].table_comment })
  }
  return tables;
}

async function getTableDetail(table) {
  const name = table.name;
  const comment = table.comment;
  const sql1 = `select column_name, is_nullable, data_type, column_type, column_key, column_comment, column_default from information_schema.COLUMNS where table_name = '${name}' and table_schema = '${database}'`;
  const sql2 = `show index from ${name}`;
  const sql3 = `show create table ${name}`;
  const res1 = await sequelize.query(sql1);
  const tableMap = getTableMap(res1[0]);
  const res2 = await sequelize.query(sql2);
  formatTableMap(tableMap, res2[0]);
  const res3 = await sequelize.query(sql3);
  return generateTable(tableMap, res3[0][0]['Create Table'], name, comment);
}

function generateTable(map, buildSql, name, comment) {
  const columns = [];
  for (let key in map) {
    columns.push(map[key]);
  }
  return {
    columns,
    buildSql,
    name,
    comment
  };
}

function getTableMap(columns) {
  let map = {};
  for (let i = 0; i < columns.length; i++) {
    map[columns[i].column_name] = {
      name: columns[i].column_name,
      is_nullable: columns[i].is_nullable,
      data_type: columns[i].data_type,
      column_type: columns[i].column_type,
      key: columns[i].column_key,
      comment: columns[i].column_comment,
      default: columns[i].column_default,
    }
  }
  return map;
}

function formatTableMap(map, columns) {

  for (let i = 0; i < columns.length; i++) {
    const column = map[columns[i].Column_name];
    const index = {
      Non_unique: columns[i].Non_unique,
      Key_name: columns[i].Key_name,
      Seq_in_index: columns[i].Seq_in_index,
      Column_name: columns[i].Column_name,
    }
    if (column.indexs) {
      column.indexs.push(index);
    } else {
      column.indexs = [index];
    }
  }
}
