const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Exams = sequelize.define('exams', {
  id: { type: Sequelize.STRING(50), allowNull: false, primaryKey: true, comment: ''},
  institution_id: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '医院id'},
  name: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '患者姓名'},
  phone: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '患者手机号'},
  card_num: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '患者身份证'},
  patient_num: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '病历号'},
  patient_id: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '患者'},
  accession_num: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '检查号'},
  hopitalized_no: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '住院号'},
  bed_no: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '病床号'},
  studyid: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '检查id'},
  studyuid: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: 'studyuid'},
  study_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '检查key'},
  exam_class: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '检查类别'},
  exam_project: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '检查项目'},
  exam_datetime: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '检查时间'},
  exam_status: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '检查状态'},
  report_result: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '检查结果'},
  report_status: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '远程诊断状态'},
  pay_status: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '支付状态'},
  status: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '1', comment: '删除状态 0 禁用 1 正常'},
  urgent: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '0', comment: '是否急诊 0 否 1是'},
  severe: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '0', comment: '重症标识 0 否 1 是'},
  film_type: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '2', comment: '胶片属性：0 未定义  1传统胶片  2电子胶片'},
  del_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '删除时间'},
  del_doctor_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '删除医师ID'},
  del_doctor_name: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '删除医师姓名'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Exams.sync({ force: false }).then(function() {});

export default Exams;
/**
 create sql
 CREATE TABLE `exams` (
  `id` varchar(50) NOT NULL,
  `institution_id` varchar(255) DEFAULT NULL COMMENT '医院id',
  `name` varchar(255) DEFAULT NULL COMMENT '患者姓名',
  `phone` varchar(255) DEFAULT NULL COMMENT '患者手机号',
  `card_num` varchar(50) DEFAULT NULL COMMENT '患者身份证',
  `patient_num` varchar(100) DEFAULT NULL COMMENT '病历号',
  `patient_id` varchar(255) DEFAULT NULL COMMENT '患者',
  `accession_num` varchar(255) DEFAULT NULL COMMENT '检查号',
  `hopitalized_no` varchar(255) DEFAULT NULL COMMENT '住院号',
  `bed_no` varchar(255) DEFAULT NULL COMMENT '病床号',
  `studyid` varchar(255) DEFAULT NULL COMMENT '检查id',
  `studyuid` varchar(255) DEFAULT NULL COMMENT 'studyuid',
  `study_id` varchar(100) DEFAULT NULL COMMENT '检查key',
  `exam_class` varchar(255) DEFAULT NULL COMMENT '检查类别',
  `exam_project` varchar(255) DEFAULT NULL COMMENT '检查项目',
  `exam_datetime` varchar(100) DEFAULT NULL COMMENT '检查时间',
  `exam_status` varchar(50) DEFAULT NULL COMMENT '检查状态',
  `report_result` varchar(255) DEFAULT NULL COMMENT '检查结果',
  `report_status` varchar(50) DEFAULT NULL COMMENT '远程诊断状态',
  `pay_status` varchar(255) DEFAULT NULL COMMENT '支付状态',
  `status` varchar(255) DEFAULT '1' COMMENT '删除状态 0 禁用 1 正常',
  `urgent` varchar(255) DEFAULT '0' COMMENT '是否急诊 0 否 1是',
  `severe` varchar(255) DEFAULT '0' COMMENT '重症标识 0 否 1 是',
  `film_type` varchar(255) DEFAULT '2' COMMENT '胶片属性：0 未定义  1传统胶片  2电子胶片',
  `del_datetime` datetime DEFAULT NULL COMMENT '删除时间',
  `del_doctor_id` varchar(50) DEFAULT NULL COMMENT '删除医师ID',
  `del_doctor_name` varchar(100) DEFAULT NULL COMMENT '删除医师姓名',
  `createdAt` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updatedAt` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `exam_id` (`id`),
  UNIQUE KEY `exam_study_id` (`study_id`),
  KEY `exam_ins` (`institution_id`),
  KEY `exam_name` (`name`),
  KEY `exam_phone` (`phone`),
  KEY `exam_card_num` (`card_num`),
  KEY `exam_patient_num` (`patient_num`),
  KEY `exam_patient_id` (`patient_id`),
  KEY `exam_accession_num` (`accession_num`),
  KEY `exam_hopitalized_no` (`hopitalized_no`),
  KEY `exam_bed_no` (`bed_no`),
  KEY `exam_studyid` (`studyid`),
  KEY `exam_studyuid` (`studyuid`),
  KEY `exam_class` (`exam_class`),
  KEY `exam_project` (`exam_project`),
  KEY `exam_datetime` (`exam_datetime`),
  KEY `exam_status` (`exam_status`),
  KEY `exam_report_result` (`report_result`),
  KEY `exam_report_status` (`report_status`),
  KEY `exam_pay_status` (`pay_status`),
  KEY `exam_urgent` (`urgent`),
  KEY `exam_severe` (`severe`),
  KEY `exam_film_type` (`film_type`),
  KEY `exam_del_datetime` (`del_datetime`),
  KEY `exam_del_doctor_id` (`del_doctor_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8
*/
