const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Report = sequelize.define('report', {
  id: { type: Sequelize.STRING(50), allowNull: false, primaryKey: true, comment: ''},
  exam_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '检查key'},
  report_doctor_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '报告医师ID'},
  report_doctor_name: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '报告医师姓名'},
  report_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '报告时间'},
  review_doctor_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '审核医师ID'},
  review_doctor_name: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '审核医师姓名'},
  review_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '审核时间'},
  confirm_doctor_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '确认医师ID'},
  confirm_doctor_name: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '确认医师姓名'},
  confirm_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '确认时间'},
  description: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '影像所见'},
  impression: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '意见建议'},
  diagnose: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '诊断'},
  qr_code: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '二维码'},
  report_result: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '报告结果 '},
  remote_application_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '申请单id'},
  type: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '1', comment: '报告类型 1 本地 2 远程'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Report.sync({ force: false }).then(function() {});

export default Report;
/**
 create sql
 CREATE TABLE `report` (
  `id` varchar(50) NOT NULL,
  `exam_id` varchar(50) DEFAULT NULL COMMENT '检查key',
  `report_doctor_id` varchar(50) DEFAULT NULL COMMENT '报告医师ID',
  `report_doctor_name` varchar(255) DEFAULT NULL COMMENT '报告医师姓名',
  `report_datetime` datetime DEFAULT NULL COMMENT '报告时间',
  `review_doctor_id` varchar(100) DEFAULT NULL COMMENT '审核医师ID',
  `review_doctor_name` varchar(255) DEFAULT NULL COMMENT '审核医师姓名',
  `review_datetime` datetime DEFAULT NULL COMMENT '审核时间',
  `confirm_doctor_id` varchar(50) DEFAULT NULL COMMENT '确认医师ID',
  `confirm_doctor_name` varchar(255) DEFAULT NULL COMMENT '确认医师姓名',
  `confirm_datetime` datetime DEFAULT NULL COMMENT '确认时间',
  `description` text COMMENT '影像所见',
  `impression` text COMMENT '意见建议',
  `diagnose` varchar(255) DEFAULT NULL COMMENT '诊断',
  `createdAt` datetime DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updatedAt` datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  `qr_code` varchar(255) DEFAULT NULL COMMENT '二维码',
  `report_result` varchar(255) DEFAULT NULL COMMENT '报告结果 ',
  `remote_application_id` varchar(50) DEFAULT NULL COMMENT '申请单id',
  `type` varchar(10) DEFAULT '1' COMMENT '报告类型 1 本地 2 远程',
  PRIMARY KEY (`id`),
  UNIQUE KEY `report_report_application` (`remote_application_id`),
  KEY `report_report_doctor_id` (`report_doctor_id`),
  KEY `report_report_datetime` (`report_datetime`),
  KEY `report_review_doctor_id` (`review_doctor_id`),
  KEY `report_confirm_doctor_id` (`confirm_doctor_id`),
  KEY `report_exam_id` (`exam_id`),
  KEY `report_confirm_datetime` (`confirm_datetime`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8
*/
