const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Doctors = sequelize.define('doctors', {
  id: { type: Sequelize.STRING(32), allowNull: false, primaryKey: true, comment: ''},
  username: { type: Sequelize.STRING(100), allowNull: false, primaryKey: false, comment: '用户名'},
  password: { type: Sequelize.STRING(200), allowNull: false, primaryKey: false, comment: '密码'},
  realname: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '真实姓名'},
  email: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: 'email'},
  login_time: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '登录时间'},
  token: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '每次登陆产生新的Session标识'},
  phone: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '电话'},
  remark: { type: Sequelize.STRING(1000), allowNull: true, primaryKey: false, comment: '备注'},
  doctor_title: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '职称'},
  status: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: ''},
  attachment: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, comment: '附件'},
  institution_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '医疗机构ID'},
  department_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '主要科室ID'},
  doctor_role: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '1.本地医生2.远程医生(可多选)'},
  login_failure: { type: Sequelize.INTEGER(11), allowNull: true, primaryKey: false, comment: '登录失败次数'},
  is_report: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, comment: '是否能写报告'},
  exam_class: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '*', comment: ''},
  send_sms: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '0', comment: '发送短信通知'},
  message_push: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '0', comment: '是否推送消息'},
  is_admin: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '0', comment: '是否为管理员'},
  is_send_message: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '0', comment: '登录是否发送短信'},
  is_use_autograph: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '0', comment: '是否使用电子签名'},
  autograph: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '电子签名'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Doctors.sync({ force: false }).then(function() {});

export default Doctors;
/**
 create sql
 CREATE TABLE `doctors` (
  `id` varchar(32) NOT NULL,
  `username` varchar(100) NOT NULL COMMENT '用户名',
  `password` varchar(200) NOT NULL COMMENT '密码',
  `realname` varchar(200) DEFAULT NULL COMMENT '真实姓名',
  `email` varchar(200) DEFAULT NULL COMMENT 'email',
  `login_time` datetime DEFAULT NULL COMMENT '登录时间',
  `createdAt` datetime DEFAULT NULL COMMENT '创建时间',
  `updatedAt` datetime DEFAULT NULL COMMENT '修改时间',
  `token` varchar(255) DEFAULT NULL COMMENT '每次登陆产生新的Session标识',
  `phone` varchar(20) DEFAULT NULL COMMENT '电话',
  `remark` varchar(1000) DEFAULT NULL COMMENT '备注',
  `doctor_title` varchar(255) DEFAULT NULL COMMENT '职称',
  `status` varchar(50) DEFAULT NULL,
  `attachment` varchar(2000) DEFAULT NULL COMMENT '附件',
  `institution_id` varchar(50) DEFAULT NULL COMMENT '医疗机构ID',
  `department_id` varchar(50) DEFAULT NULL COMMENT '主要科室ID',
  `doctor_role` varchar(20) DEFAULT NULL COMMENT '1.本地医生2.远程医生(可多选)',
  `login_failure` int(11) DEFAULT NULL COMMENT '登录失败次数',
  `is_report` varchar(10) DEFAULT NULL COMMENT '是否能写报告',
  `exam_class` varchar(255) DEFAULT '*',
  `send_sms` varchar(10) DEFAULT '0' COMMENT '发送短信通知',
  `message_push` varchar(10) DEFAULT '0' COMMENT '是否推送消息',
  `is_admin` varchar(255) DEFAULT '0' COMMENT '是否为管理员',
  `is_send_message` varchar(255) DEFAULT '0' COMMENT '登录是否发送短信',
  `is_use_autograph` varchar(255) DEFAULT '0' COMMENT '是否使用电子签名',
  `autograph` varchar(255) DEFAULT NULL COMMENT '电子签名',
  PRIMARY KEY (`id`),
  KEY `doc-institu` (`institution_id`),
  KEY `doc-depart` (`department_id`),
  KEY `doc-report` (`is_report`),
  KEY `doc-username` (`username`),
  KEY `doctors_institution_id` (`institution_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='医生表'
*/
