const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Exams = sequelize.define('exams', {
  id: { type: Sequelize.STRING(32), allowNull: false, primaryKey: true, comment: ''},
  dept_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '检查科室（执行科室）'},
  patient_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '患者id'},
  patient_num: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '病历号'},
  accession_num: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '科室检查号'},
  exam_datetime: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '检查日期'},
  exam_class: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '检查类型'},
  exam_sub_class: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '检查子类'},
  exam_project: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '检查项目'},
  device: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '检查设备'},
  body_part: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '检查部位'},
  exam_method: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '检查方法'},
  hopitalized_no: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '住院号'},
  bed_no: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '床位号'},
  clin_dept_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '送诊科室id'},
  technician: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '技师'},
  charge: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '检查费用'},
  cost: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '实际费用'},
  clin_doctors: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '送诊医生'},
  phone: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '联系方式'},
  institution_id: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '医院id'},
  study_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: 'studyuid（studykey）'},
  illness_desc: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '主诉'},
  phys_sign: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '体征'},
  clin_diag: { type: Sequelize.STRING(1000), allowNull: true, primaryKey: false, comment: '临床诊断'},
  clin_symp: { type: Sequelize.STRING(4000), allowNull: true, primaryKey: false, comment: '临床症状'},
  patient_source: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '病人来源 1门诊 2住院 3外来'},
  req_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '申请时间'},
  req_doctor: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '申请医生（医生id）'},
  remark: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '其他说明'},
  register: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '登记人员( 医生id)'},
  register_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '注册登记时间'},
  exam_status: { type: Sequelize.TINYINT(6), allowNull: true, primaryKey: false, defaultValue: '1', comment: '1、登记 2、开始检查3、检查完毕 4、申请 5、驳回 6、接收、7、初步报告 8、审核报告 9、确认、'},
  status: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, defaultValue: '1', comment: '记录状态 0禁用 1正常'},
  pay_status: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '0', comment: '支付状态'},
  is_remote: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, comment: '远程诊断是被接受 0,未接受  1,已接受'},
  urgent: { type: Sequelize.STRING(10), allowNull: false, primaryKey: false, defaultValue: '0', comment: '是否急诊 0否  1是'},
  film_type: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, defaultValue: '2', comment: '0 未定义  1传统胶片  2电子胶片'},
  anamnesis: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: ''},
  family_ill: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: ''},
  delivery_doctor: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '送诊医生'},
  exam_report: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, comment: '检查结果'},
  ext: { type: Sequelize.JSON, allowNull: true, primaryKey: false, comment: ''},
  id_card: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '身份证号'},
  study_uid: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: ''},
  application_department: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '申请科室'},
  application_doctor: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '申请医生'},
  severe: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, defaultValue: '0', comment: '重症标识'},
  patient_area: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '病区'},
  del_doctor_name: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '删除信息的医生姓名'},
  del_time: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: ''},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Exams.sync({ force: false }).then(function() {});

export default Exams;
/**
 create sql
 CREATE TABLE `exams` (
  `id` varchar(32) NOT NULL,
  `dept_id` varchar(100) DEFAULT NULL COMMENT '检查科室（执行科室）',
  `patient_id` varchar(100) DEFAULT NULL COMMENT '患者id',
  `patient_num` varchar(200) DEFAULT NULL COMMENT '病历号',
  `accession_num` varchar(100) DEFAULT NULL COMMENT '科室检查号',
  `exam_datetime` varchar(20) DEFAULT NULL COMMENT '检查日期',
  `exam_class` varchar(200) DEFAULT NULL COMMENT '检查类型',
  `exam_sub_class` varchar(200) DEFAULT NULL COMMENT '检查子类',
  `exam_project` varchar(200) DEFAULT NULL COMMENT '检查项目',
  `device` varchar(200) DEFAULT NULL COMMENT '检查设备',
  `body_part` varchar(200) DEFAULT NULL COMMENT '检查部位',
  `exam_method` varchar(200) DEFAULT NULL COMMENT '检查方法',
  `hopitalized_no` varchar(200) DEFAULT NULL COMMENT '住院号',
  `bed_no` varchar(200) DEFAULT NULL COMMENT '床位号',
  `clin_dept_id` varchar(50) DEFAULT NULL COMMENT '送诊科室id',
  `technician` varchar(200) DEFAULT NULL COMMENT '技师',
  `charge` varchar(200) DEFAULT NULL COMMENT '检查费用',
  `cost` varchar(200) DEFAULT NULL COMMENT '实际费用',
  `clin_doctors` varchar(200) DEFAULT NULL COMMENT '送诊医生',
  `phone` varchar(20) DEFAULT NULL COMMENT '联系方式',
  `institution_id` varchar(200) DEFAULT NULL COMMENT '医院id',
  `study_id` varchar(50) DEFAULT NULL COMMENT 'studyuid（studykey）',
  `illness_desc` text COMMENT '主诉',
  `phys_sign` varchar(200) DEFAULT NULL COMMENT '体征',
  `clin_diag` varchar(1000) DEFAULT NULL COMMENT '临床诊断',
  `clin_symp` varchar(4000) DEFAULT NULL COMMENT '临床症状',
  `patient_source` varchar(20) DEFAULT NULL COMMENT '病人来源 1门诊 2住院 3外来',
  `req_datetime` datetime DEFAULT NULL COMMENT '申请时间',
  `req_doctor` varchar(50) DEFAULT NULL COMMENT '申请医生（医生id）',
  `remark` text COMMENT '其他说明',
  `register` varchar(50) DEFAULT NULL COMMENT '登记人员( 医生id)',
  `register_datetime` datetime DEFAULT NULL COMMENT '注册登记时间',
  `exam_status` tinyint(6) DEFAULT '1' COMMENT '1、登记 2、开始检查3、检查完毕 4、申请 5、驳回 6、接收、7、初步报告 8、审核报告 9、确认、',
  `status` varchar(20) DEFAULT '1' COMMENT '记录状态 0禁用 1正常',
  `pay_status` varchar(10) DEFAULT '0' COMMENT '支付状态',
  `is_remote` varchar(10) DEFAULT NULL COMMENT '远程诊断是被接受 0,未接受  1,已接受',
  `urgent` varchar(10) NOT NULL DEFAULT '0' COMMENT '是否急诊 0否  1是',
  `film_type` varchar(20) DEFAULT '2' COMMENT '0 未定义  1传统胶片  2电子胶片',
  `anamnesis` varchar(255) DEFAULT NULL,
  `family_ill` varchar(255) DEFAULT NULL,
  `createdAt` datetime DEFAULT NULL,
  `updatedAt` datetime DEFAULT NULL,
  `delivery_doctor` varchar(100) DEFAULT NULL COMMENT '送诊医生',
  `exam_report` varchar(10) DEFAULT NULL COMMENT '检查结果',
  `ext` json DEFAULT NULL,
  `id_card` varchar(50) DEFAULT NULL COMMENT '身份证号',
  `study_uid` varchar(100) DEFAULT NULL,
  `application_department` varchar(255) DEFAULT NULL COMMENT '申请科室',
  `application_doctor` varchar(255) DEFAULT NULL COMMENT '申请医生',
  `severe` varchar(255) DEFAULT '0' COMMENT '重症标识',
  `patient_area` varchar(255) DEFAULT NULL COMMENT '病区',
  `del_doctor_name` varchar(255) DEFAULT NULL COMMENT '删除信息的医生姓名',
  `del_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `exam-study_id` (`study_id`),
  KEY `exam-institution` (`institution_id`),
  KEY `exam-urgent` (`urgent`),
  KEY `exam-remote` (`is_remote`),
  KEY `exam-status` (`exam_status`),
  KEY `exam-report` (`exam_report`),
  KEY `exam-project` (`exam_project`) USING BTREE,
  KEY `exam-device` (`device`),
  KEY `exam-body` (`body_part`),
  KEY `exams_exam_datetime` (`exam_datetime`),
  KEY `exams_exam_class` (`exam_class`),
  KEY `exams_exam_status` (`exam_status`),
  KEY `exams_patient_num` (`patient_num`),
  KEY `exams_patient_id` (`patient_id`),
  KEY `exams_study_id` (`study_id`),
  KEY `exams_institution_id` (`institution_id`),
  KEY `exams_idcard` (`id_card`),
  KEY `studyuid_index` (`study_uid`),
  KEY `created_index` (`createdAt`),
  KEY `accnum_index` (`accession_num`),
  KEY `i_c_index` (`institution_id`,`createdAt`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='检查表'
*/
