const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Patient_infos = sequelize.define('patient_infos', {
  id: { type: Sequelize.STRING(32), allowNull: false, primaryKey: true, comment: ''},
  name: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '患者姓名'},
  sex: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, comment: '性别'},
  card_num: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '身份证号'},
  phone: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '手机号'},
  ctime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '创建时间'},
  birthday: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '生日'},
  age: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, comment: '年龄'},
  card_type: { type: Sequelize.STRING(30), allowNull: true, primaryKey: false, comment: '证件类型'},
  nationality: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '国籍'},
  nation: { type: Sequelize.STRING(30), allowNull: true, primaryKey: false, defaultValue: '', comment: '民族'},
  marry: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, comment: '婚否'},
  professional: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '职业'},
  address: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '联系地址'},
  temp_patient_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '检查临时患者id(从dicom影像中解析）'},
  status: { type: Sequelize.INTEGER(10), allowNull: false, primaryKey: false, defaultValue: '1', comment: ''},
  institution_id: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '所属医院'},
  anamnesis: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '疾病史'},
  family_ill: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '家族史'},
  ext: { type: Sequelize.JSON, allowNull: true, primaryKey: false, comment: ''},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Patient_infos.sync({ force: false }).then(function() {});

export default Patient_infos;
/**
 create sql
 CREATE TABLE `patient_infos` (
  `id` varchar(32) NOT NULL,
  `name` varchar(100) DEFAULT NULL COMMENT '患者姓名',
  `sex` varchar(10) DEFAULT NULL COMMENT '性别',
  `card_num` varchar(100) DEFAULT NULL COMMENT '身份证号',
  `phone` varchar(20) DEFAULT NULL COMMENT '手机号',
  `ctime` datetime DEFAULT NULL COMMENT '创建时间',
  `birthday` varchar(20) DEFAULT NULL COMMENT '生日',
  `age` varchar(10) DEFAULT NULL COMMENT '年龄',
  `card_type` varchar(30) DEFAULT NULL COMMENT '证件类型',
  `nationality` varchar(50) DEFAULT NULL COMMENT '国籍',
  `nation` varchar(30) DEFAULT '' COMMENT '民族',
  `marry` varchar(10) DEFAULT NULL COMMENT '婚否',
  `professional` varchar(100) DEFAULT NULL COMMENT '职业',
  `address` varchar(255) DEFAULT NULL COMMENT '联系地址',
  `temp_patient_id` varchar(50) DEFAULT NULL COMMENT '检查临时患者id(从dicom影像中解析）',
  `status` int(10) NOT NULL DEFAULT '1',
  `institution_id` varchar(200) DEFAULT NULL COMMENT '所属医院',
  `anamnesis` varchar(255) DEFAULT NULL COMMENT '疾病史',
  `family_ill` varchar(255) DEFAULT NULL COMMENT '家族史',
  `createdAt` datetime DEFAULT NULL,
  `updatedAt` datetime DEFAULT NULL,
  `ext` json DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `parentinfo-institution` (`institution_id`),
  KEY `card_num` (`card_num`),
  KEY `patient_infos_institution_id` (`institution_id`),
  KEY `patient_infos_temp_patient_id` (`temp_patient_id`),
  KEY `patient_infos_phone` (`phone`),
  KEY `patient_id_index` (`temp_patient_id`),
  KEY `card_num_index` (`card_num`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='患者信息表'
*/
