const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Remote_contact = sequelize.define('remote_contact', {
  id: { type: Sequelize.INTEGER(32), allowNull: false, primaryKey: true, comment: 'id'},
  hospital_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '下级医院'},
  super_hospital_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '上级医院'},
  remark: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '备注'},
  lower_ratio: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '35', comment: '下级比例'},
  pay_type: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '支付类型 默认0 医院挂账 1 是患者支付'},
  super_ratio: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '50', comment: '上级比例'},
  zskk_ratio: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '15', comment: 'zskk比例'},
  timestamp: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '时间戳'},
  sort: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '顺序号'},
  hospital_name: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '下级医院名称'},
  super_hospital_name: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '上级医院名称'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Remote_contact.sync({ force: false }).then(function() {});

export default Remote_contact;
/**
 create sql
 CREATE TABLE `remote_contact` (
  `id` int(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
  `hospital_id` varchar(32) DEFAULT NULL COMMENT '下级医院',
  `super_hospital_id` varchar(32) DEFAULT NULL COMMENT '上级医院',
  `remark` text COMMENT '备注',
  `lower_ratio` int(11) NOT NULL DEFAULT '35' COMMENT '下级比例',
  `pay_type` int(11) NOT NULL DEFAULT '0' COMMENT '支付类型 默认0 医院挂账 1 是患者支付',
  `super_ratio` int(11) NOT NULL DEFAULT '50' COMMENT '上级比例',
  `zskk_ratio` int(11) NOT NULL DEFAULT '15' COMMENT 'zskk比例',
  `createdAt` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT '时间戳',
  `sort` int(11) NOT NULL DEFAULT '0' COMMENT '顺序号',
  `hospital_name` varchar(100) DEFAULT NULL COMMENT '下级医院名称',
  `super_hospital_name` varchar(100) DEFAULT NULL COMMENT '上级医院名称',
  PRIMARY KEY (`id`),
  KEY `hospital_id_index` (`hospital_id`),
  KEY `super_hospital_id_index` (`super_hospital_id`),
  KEY `timestamp_index` (`timestamp`)
) ENGINE=InnoDB AUTO_INCREMENT=93 DEFAULT CHARSET=utf8 COMMENT='远程诊断关系表'
*/
