const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Remote_order = sequelize.define('remote_order', {
  id: { type: Sequelize.STRING(32), allowNull: false, primaryKey: true, comment: 'id'},
  hospital_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '医院名'},
  super_hospital_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '医院地址'},
  exam_class: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '检查类型'},
  doctor_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '本地医生'},
  application_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '申请单号'},
  super_doctor_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '远程医生'},
  remark: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '备注'},
  order_money: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '订单费用'},
  pay_type: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '支付类型 患者/医院'},
  pay_way: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '支付方式 微信 支付宝 银联 挂账 等'},
  timestamp: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '时间戳'},
  status: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '订单状态'},
  is_urgent: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '是否急诊'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Remote_order.sync({ force: false }).then(function() {});

export default Remote_order;
/**
 create sql
 CREATE TABLE `remote_order` (
  `id` varchar(32) NOT NULL COMMENT 'id',
  `hospital_id` varchar(32) DEFAULT NULL COMMENT '医院名',
  `super_hospital_id` varchar(32) DEFAULT NULL COMMENT '医院地址',
  `exam_class` varchar(32) DEFAULT NULL COMMENT '检查类型',
  `doctor_id` varchar(32) DEFAULT NULL COMMENT '本地医生',
  `application_id` varchar(32) DEFAULT NULL COMMENT '申请单号',
  `super_doctor_id` varchar(32) DEFAULT NULL COMMENT '远程医生',
  `remark` text COMMENT '备注',
  `order_money` int(11) NOT NULL DEFAULT '0' COMMENT '订单费用',
  `pay_type` int(11) NOT NULL DEFAULT '0' COMMENT '支付类型 患者/医院',
  `pay_way` int(11) NOT NULL DEFAULT '0' COMMENT '支付方式 微信 支付宝 银联 挂账 等',
  `createdAt` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT '时间戳',
  `status` int(11) NOT NULL DEFAULT '0' COMMENT '订单状态',
  `is_urgent` int(11) NOT NULL DEFAULT '0' COMMENT '是否急诊',
  PRIMARY KEY (`id`),
  KEY `hospital_id_index` (`hospital_id`),
  KEY `super_hospital_id_index` (`super_hospital_id`),
  KEY `exam_class_index` (`exam_class`),
  KEY `doctor_id_index` (`doctor_id`),
  KEY `application_id_index` (`application_id`),
  KEY `super_doctor_id_index` (`super_doctor_id`),
  KEY `pay_type_index` (`pay_type`),
  KEY `pay_way_index` (`pay_way`),
  KEY `timestamp_index` (`timestamp`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='远程诊断订单表'
*/
