const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Report = sequelize.define('report', {
  id: { type: Sequelize.STRING(32), allowNull: false, primaryKey: true, comment: '报告id'},
  report_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '报告时间'},
  description: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '检查所见'},
  impression: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '意见建议'},
  img_url: { type: Sequelize.STRING(1500), allowNull: true, primaryKey: false, comment: '缩略图地址'},
  exam_id: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '检查表id'},
  report_doctor_id: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '报告医生id'},
  review_doctor_id: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '审核医生id'},
  qr_code: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '二维码'},
  report_result: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '报告结果（阴阳性） 1阴性 2阳性'},
  review_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '审核时间'},
  confirm_doctor_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '确认医生'},
  confirm_datetime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '确认时间'},
  type: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '1', comment: '报告类型'},
  remote_application_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '申请id'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: false,
});

Report.sync({ force: false }).then(function() {});

export default Report;
/**
 create sql
 CREATE TABLE `report` (
  `id` varchar(32) NOT NULL COMMENT '报告id',
  `report_datetime` datetime DEFAULT NULL COMMENT '报告时间',
  `description` text COMMENT '检查所见',
  `impression` text COMMENT '意见建议',
  `img_url` varchar(1500) DEFAULT NULL COMMENT '缩略图地址',
  `exam_id` varchar(255) DEFAULT NULL COMMENT '检查表id',
  `createdAt` datetime DEFAULT NULL,
  `report_doctor_id` varchar(255) DEFAULT NULL COMMENT '报告医生id',
  `review_doctor_id` varchar(255) DEFAULT NULL COMMENT '审核医生id',
  `qr_code` varchar(255) DEFAULT NULL COMMENT '二维码',
  `report_result` varchar(255) DEFAULT NULL COMMENT '报告结果（阴阳性） 1阴性 2阳性',
  `review_datetime` datetime DEFAULT NULL COMMENT '审核时间',
  `confirm_doctor_id` varchar(50) DEFAULT NULL COMMENT '确认医生',
  `confirm_datetime` datetime DEFAULT NULL COMMENT '确认时间',
  `type` varchar(10) DEFAULT '1' COMMENT '报告类型',
  `remote_application_id` varchar(50) DEFAULT NULL COMMENT '申请id',
  PRIMARY KEY (`id`),
  KEY `唯一` (`exam_id`) USING BTREE,
  KEY `report-doctor` (`report_doctor_id`) USING BTREE,
  KEY `report-review_doctor` (`review_doctor_id`) USING BTREE,
  KEY `report-confirm_doctor` (`confirm_doctor_id`) USING BTREE,
  KEY `remote_application_id_index` (`remote_application_id`),
  KEY `report_exam_id` (`exam_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='诊断报告'
*/
