const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Fa_test = sequelize.define('fa_test', {
  id: { type: Sequelize.INTEGER(10), allowNull: false, primaryKey: true, comment: 'ID' },
  admin_id: { type: Sequelize.INTEGER(10), allowNull: false, primaryKey: false, defaultValue: '0', comment: '管理员ID' },
  category_id: { type: Sequelize.INTEGER(10), allowNull: false, primaryKey: false, defaultValue: '0', comment: '分类ID(单选)' },
  category_ids: { type: Sequelize.STRING(100), allowNull: false, primaryKey: false, comment: '分类ID(多选)' },
  week: { type: Sequelize.enum('monday', 'tuesday', 'wednesday'), allowNull: false, primaryKey: false, comment: '星期(单选):monday=星期一,tuesday=星期二,wednesday=星期三' },
  flag: { type: Sequelize.set('hot', 'index', 'recommend'), allowNull: false, primaryKey: false, defaultValue: '', comment: '标志(多选):hot=热门,index=首页,recommend=推荐' },
  genderdata: { type: Sequelize.enum('male', 'female'), allowNull: false, primaryKey: false, defaultValue: 'male', comment: '性别(单选):male=男,female=女' },
  hobbydata: { type: Sequelize.set('music', 'reading', 'swimming'), allowNull: false, primaryKey: false, comment: '爱好(多选):music=音乐,reading=读书,swimming=游泳' },
  title: { type: Sequelize.STRING(50), allowNull: false, primaryKey: false, defaultValue: '', comment: '标题' },
  content: { type: Sequelize.TEXT, allowNull: false, primaryKey: false, comment: '内容' },
  image: { type: Sequelize.STRING(100), allowNull: false, primaryKey: false, defaultValue: '', comment: '图片' },
  images: { type: Sequelize.STRING(1500), allowNull: false, primaryKey: false, defaultValue: '', comment: '图片组' },
  attachfile: { type: Sequelize.STRING(100), allowNull: false, primaryKey: false, defaultValue: '', comment: '附件' },
  keywords: { type: Sequelize.STRING(100), allowNull: false, primaryKey: false, defaultValue: '', comment: '关键字' },
  description: { type: Sequelize.STRING(255), allowNull: false, primaryKey: false, defaultValue: '', comment: '描述' },
  city: { type: Sequelize.STRING(100), allowNull: false, primaryKey: false, defaultValue: '', comment: '省市' },
  json: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '配置:key=名称,value=值' },
  price: { type: Sequelize.float(10, 2), allowNull: false, primaryKey: false, defaultValue: '0.00', comment: '价格' },
  views: { type: Sequelize.INTEGER(10), allowNull: false, primaryKey: false, defaultValue: '0', comment: '点击' },
  startdate: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '开始日期' },
  activitytime: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '活动时间(datetime)' },
  year: { type: Sequelize.year(4), allowNull: true, primaryKey: false, comment: '年' },
  times: { type: Sequelize.time, allowNull: true, primaryKey: false, comment: '时间' },
  refreshtime: { type: Sequelize.INTEGER(10), allowNull: true, primaryKey: false, comment: '刷新时间(int)' },
  createtime: { type: Sequelize.INTEGER(10), allowNull: true, primaryKey: false, comment: '创建时间' },
  updatetime: { type: Sequelize.INTEGER(10), allowNull: true, primaryKey: false, comment: '更新时间' },
  deletetime: { type: Sequelize.INTEGER(10), allowNull: true, primaryKey: false, comment: '删除时间' },
  weigh: { type: Sequelize.INTEGER(10), allowNull: false, primaryKey: false, defaultValue: '0', comment: '权重' },
  switch: { type: Sequelize.TINYINT(1), allowNull: false, primaryKey: false, defaultValue: '0', comment: '开关' },
  status: { type: Sequelize.enum('normal', 'hidden'), allowNull: false, primaryKey: false, defaultValue: 'normal', comment: '状态' },
  state: { type: Sequelize.enum('0', '1', '2'), allowNull: false, primaryKey: false, defaultValue: '1', comment: '状态值:0=禁用,1=正常,2=推荐' },
}, {
  freezeTableName: true,
  charset: 'utf8',
  createdAt: false,
  updatedAt: false,
});

Fa_test.sync({ force: false }).then(function() {});

export default Fa_test;
/**
 create sql
 CREATE TABLE `fa_test` (
  `id` int(10)  NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `admin_id` int(10) NOT NULL DEFAULT '0' COMMENT '管理员ID',
  `category_id` int(10)  NOT NULL DEFAULT '0' COMMENT '分类ID(单选)',
  `category_ids` varchar(100) NOT NULL COMMENT '分类ID(多选)',
  `week` enum('monday','tuesday','wednesday') NOT NULL COMMENT '星期(单选):monday=星期一,tuesday=星期二,wednesday=星期三',
  `flag` set('hot','index','recommend') NOT NULL DEFAULT '' COMMENT '标志(多选):hot=热门,index=首页,recommend=推荐',
  `genderdata` enum('male','female') NOT NULL DEFAULT 'male' COMMENT '性别(单选):male=男,female=女',
  `hobbydata` set('music','reading','swimming') NOT NULL COMMENT '爱好(多选):music=音乐,reading=读书,swimming=游泳',
  `title` varchar(50) NOT NULL DEFAULT '' COMMENT '标题',
  `content` text NOT NULL COMMENT '内容',
  `image` varchar(100) NOT NULL DEFAULT '' COMMENT '图片',
  `images` varchar(1500) NOT NULL DEFAULT '' COMMENT '图片组',
  `attachfile` varchar(100) NOT NULL DEFAULT '' COMMENT '附件',
  `keywords` varchar(100) NOT NULL DEFAULT '' COMMENT '关键字',
  `description` varchar(255) NOT NULL DEFAULT '' COMMENT '描述',
  `city` varchar(100) NOT NULL DEFAULT '' COMMENT '省市',
  `json` varchar(255) DEFAULT NULL COMMENT '配置:key=名称,value=值',
  `price` float(10,2)  NOT NULL DEFAULT '0.00' COMMENT '价格',
  `views` int(10)  NOT NULL DEFAULT '0' COMMENT '点击',
  `startdate` date DEFAULT NULL COMMENT '开始日期',
  `activitytime` datetime DEFAULT NULL COMMENT '活动时间(datetime)',
  `year` year(4) DEFAULT NULL COMMENT '年',
  `times` time DEFAULT NULL COMMENT '时间',
  `refreshtime` int(10) DEFAULT NULL COMMENT '刷新时间(int)',
  `createtime` int(10) DEFAULT NULL COMMENT '创建时间',
  `updatetime` int(10) DEFAULT NULL COMMENT '更新时间',
  `deletetime` int(10) DEFAULT NULL COMMENT '删除时间',
  `weigh` int(10) NOT NULL DEFAULT '0' COMMENT '权重',
  `switch` tinyint(1) NOT NULL DEFAULT '0' COMMENT '开关',
  `status` enum('normal','hidden') NOT NULL DEFAULT 'normal' COMMENT '状态',
  `state` enum('0','1','2') NOT NULL DEFAULT '1' COMMENT '状态值:0=禁用,1=正常,2=推荐',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8 ROW_FORMAT=COMPACT COMMENT='测试表'
*/
