const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Institution = sequelize.define('institution', {
  id: { type: Sequelize.STRING(32), allowNull: false, primaryKey: true, comment: '机构代码'},
  name: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '医院名'},
  address: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '医院地址'},
  remark: { type: Sequelize.TEXT, allowNull: true, primaryKey: false, comment: '备注'},
  status: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: ''},
  institution_level: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '医疗机构等级'},
  parent_institution: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '上级机构(多对多关系)'},
  charge_mode: { type: Sequelize.STRING(20), allowNull: true, primaryKey: false, comment: '收费模式 1.向患者结算 2.向医院结算'},
  local_domain: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: 'http://local.pacsonline.cn/img/189290/**.jpg'},
  report_subtitle: { type: Sequelize.STRING(200), allowNull: true, primaryKey: false, comment: '报告副标题'},
  agent_id: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '代理商 关联manage表'},
  msg_phone: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: ''},
  urgent_time: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: ''},
  not_urgent_time: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: ''},
  wx_source: { type: Sequelize.STRING(64), allowNull: false, primaryKey: false, defaultValue: '中世康恺电子胶片平台', comment: '医疗机构所属微信公众号'},
  is_test: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '0', comment: ''},
  current_money: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '账户余额'},
  min_money: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '最低金额(额度)'},
  notice_monoy: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '通知金额'},
  is_pay: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '是否付费 默认0 不付费 1为付费'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Institution.sync({ force: false }).then(function() {});

export default Institution;
/**
 create sql
 CREATE TABLE `institution` (
  `id` varchar(32) NOT NULL COMMENT '机构代码',
  `name` varchar(200) DEFAULT NULL COMMENT '医院名',
  `address` varchar(200) DEFAULT NULL COMMENT '医院地址',
  `remark` text COMMENT '备注',
  `status` varchar(20) DEFAULT NULL,
  `createdAt` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `updatedAt` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `institution_level` varchar(200) DEFAULT NULL COMMENT '医疗机构等级',
  `parent_institution` varchar(100) DEFAULT NULL COMMENT '上级机构(多对多关系)',
  `charge_mode` varchar(20) DEFAULT NULL COMMENT '收费模式 1.向患者结算 2.向医院结算',
  `local_domain` varchar(255) DEFAULT NULL COMMENT 'http://local.pacsonline.cn/img/189290/**.jpg',
  `report_subtitle` varchar(200) DEFAULT NULL COMMENT '报告副标题',
  `agent_id` varchar(50) DEFAULT NULL COMMENT '代理商 关联manage表',
  `msg_phone` varchar(50) DEFAULT NULL,
  `urgent_time` datetime DEFAULT NULL,
  `not_urgent_time` datetime DEFAULT NULL,
  `wx_source` varchar(64) NOT NULL DEFAULT '中世康恺电子胶片平台' COMMENT '医疗机构所属微信公众号',
  `is_test` varchar(10) DEFAULT '0',
  `current_money` int(11) NOT NULL DEFAULT '0' COMMENT '账户余额',
  `min_money` int(11) NOT NULL DEFAULT '0' COMMENT '最低金额(额度)',
  `notice_monoy` int(11) NOT NULL DEFAULT '0' COMMENT '通知金额',
  `is_pay` int(11) NOT NULL DEFAULT '0' COMMENT '是否付费 默认0 不付费 1为付费',
  PRIMARY KEY (`id`),
  KEY `institution-parent` (`parent_institution`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='医疗机构表'
*/
