const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Remote_application = sequelize.define('remote_application', {
  id: { type: Sequelize.STRING(32), allowNull: false, primaryKey: true, comment: ''},
  remote_institution_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '申请的目标医院'},
  remote_doctor_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '申请的目标医生'},
  local_institution_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '发起申请医院'},
  req_date_time: { type: Sequelize.DATE, allowNull: true, primaryKey: false, comment: '发起时间'},
  req_doctor_id: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '申请医生'},
  illness_desc: { type: Sequelize.STRING(2000), allowNull: false, primaryKey: false, comment: '主诉'},
  clin_symp: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, comment: '临床症状'},
  phys_sign: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, comment: '体征'},
  clin_diag: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, comment: '临床诊断'},
  anamnesis: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, comment: '既往史'},
  family_ill: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, comment: '家族史'},
  marrital: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, defaultValue: '', comment: '婚姻史'},
  remark: { type: Sequelize.STRING(4000), allowNull: true, primaryKey: false, comment: '备注'},
  exam_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '检查表id'},
  is_urgent: { type: Sequelize.STRING(10), allowNull: false, primaryKey: false, defaultValue: '0', comment: '是否急诊 0否  1是'},
  status: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '0', comment: '删除状态'},
  application_desc: { type: Sequelize.STRING(2000), allowNull: true, primaryKey: false, comment: '申请描述'},
  attachment: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '附件'},
  report_status: { type: Sequelize.STRING(10), allowNull: true, primaryKey: false, defaultValue: '', comment: '4、申请 5、驳回 6、接收、7、初步报告 8、审核报告 9、确认、'},
  remote_department: { type: Sequelize.STRING(50), allowNull: true, primaryKey: false, comment: '申请科室'},
  more: { type: Sequelize.STRING(255), allowNull: true, primaryKey: false, comment: '补充说明'},
  odd_number: { type: Sequelize.STRING(100), allowNull: true, primaryKey: false, comment: '申请单单号'},
},{
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: false,
});

Remote_application.sync({ force: false }).then(function() {});

export default Remote_application;
/**
 create sql
 CREATE TABLE `remote_application` (
  `id` varchar(32) NOT NULL,
  `remote_institution_id` varchar(100) DEFAULT NULL COMMENT '申请的目标医院',
  `remote_doctor_id` varchar(100) DEFAULT NULL COMMENT '申请的目标医生',
  `local_institution_id` varchar(100) DEFAULT NULL COMMENT '发起申请医院',
  `req_date_time` datetime DEFAULT NULL COMMENT '发起时间',
  `req_doctor_id` varchar(100) DEFAULT NULL COMMENT '申请医生',
  `illness_desc` varchar(2000) NOT NULL COMMENT '主诉',
  `clin_symp` varchar(2000) DEFAULT NULL COMMENT '临床症状',
  `phys_sign` varchar(2000) DEFAULT NULL COMMENT '体征',
  `clin_diag` varchar(2000) DEFAULT NULL COMMENT '临床诊断',
  `anamnesis` varchar(2000) DEFAULT NULL COMMENT '既往史',
  `family_ill` varchar(2000) DEFAULT NULL COMMENT '家族史',
  `marrital` varchar(2000) DEFAULT '' COMMENT '婚姻史',
  `remark` varchar(4000) DEFAULT NULL COMMENT '备注',
  `exam_id` varchar(32) DEFAULT NULL COMMENT '检查表id',
  `is_urgent` varchar(10) NOT NULL DEFAULT '0' COMMENT '是否急诊 0否  1是',
  `status` varchar(10) DEFAULT '0' COMMENT '删除状态',
  `createdAt` datetime DEFAULT NULL COMMENT '创建时间',
  `application_desc` varchar(2000) DEFAULT NULL COMMENT '申请描述',
  `attachment` varchar(255) DEFAULT NULL COMMENT '附件',
  `report_status` varchar(10) DEFAULT '' COMMENT '4、申请 5、驳回 6、接收、7、初步报告 8、审核报告 9、确认、',
  `remote_department` varchar(50) DEFAULT NULL COMMENT '申请科室',
  `more` varchar(255) DEFAULT NULL COMMENT '补充说明',
  `odd_number` varchar(100) DEFAULT NULL COMMENT '申请单单号',
  PRIMARY KEY (`id`),
  KEY `application-remote-institution` (`remote_institution_id`),
  KEY `local_institution_id` (`local_institution_id`),
  KEY `application-remote_doctor` (`remote_doctor_id`) USING BTREE,
  KEY `application-req_doctor` (`req_doctor_id`) USING BTREE,
  KEY `application-is_urgent` (`is_urgent`) USING BTREE,
  KEY `application--exam_id` (`exam_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='申请表'
*/
