const Sequelize = require('sequelize');
import sequelize from './db/sequelize';

const Wechat_refund_log = sequelize.define('wechat_refund_log', {
  id: { type: Sequelize.INTEGER(32), allowNull: false, primaryKey: true, comment: 'id' },
  appid: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '公众账号ID' },
  mch_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '0', comment: '退款的商户号' },
  nonce_str: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '0', comment: '随机字符串' },
  req_info: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '加密信息' },
  out_refund_no: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '商户退款单号' },
  out_trade_no: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '商户订单号' },
  refund_account: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '退款资金来源 REFUND_SOURCE_RECHARGE_FUNDS 可用余额退款/基本账户 REFUND_SOURCE_UNSETTLED_FUNDS 未结算资金退款' },
  refund_fee: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '0', comment: '申请退款金额 退款总金额,单位为分' },
  refund_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '微信退款单号' },
  refund_recv_accout: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '退款入账账户 取当前退款单的退款入账方 1）退回银行卡： {银行名称}{卡类型}{卡尾号} 2）退回支付用户零钱: 支付用户零钱 3）退还商户: 商户基本账户 商户结算银行账户 4）退回支付用户零钱通: 支付用户零钱通' },
  refund_request_source: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '退款状态 SUCCESS-退款成功 CHANGE-退款异常 REFUNDCLOSE—退款关闭' },
  refund_status: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '退款发起来源 API接口VENDOR_PLATFORM商户平台' },
  settlement_refund_fee: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '退款金额 退款金额=申请退款金额-非充值代金券退款金额，退款金额<=申请退款金额' },
  settlement_total_fee: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '应结订单金额 当该订单有使用非充值券时，返回此字段。应结订单金额=订单金额-非充值代金券金额，应结订单金额<=订单金额' },
  success_time: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '退款成功时间 资金退款至用户帐号的时间，格式2017-12-15 09:46:01' },
  total_fee: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, defaultValue: '', comment: '订单金额 订单总金额，单位为分，只能为整数' },
  transaction_id: { type: Sequelize.STRING(32), allowNull: true, primaryKey: false, comment: '微信订单号' },
  timestamp: { type: Sequelize.INTEGER(11), allowNull: false, primaryKey: false, defaultValue: '0', comment: '时间戳' },
}, {
  freezeTableName: true,
  charset: 'utf8',
  createdAt: 'createdAt',
  updatedAt: 'updatedAt',
});

Wechat_refund_log.sync({ force: false }).then(function() {});

export default Wechat_refund_log;
/**
 create sql
 CREATE TABLE `wechat_refund_log` (
  `id` int(32) NOT NULL AUTO_INCREMENT COMMENT 'id',
  `appid` varchar(32) DEFAULT NULL COMMENT '公众账号ID',
  `mch_id` varchar(32) DEFAULT '0' COMMENT '退款的商户号',
  `nonce_str` varbinary(32) DEFAULT '0' COMMENT '随机字符串',
  `req_info` varchar(32) DEFAULT NULL COMMENT '加密信息',
  `out_refund_no` varchar(32) DEFAULT NULL COMMENT '商户退款单号',
  `out_trade_no` varchar(32) DEFAULT NULL COMMENT '商户订单号',
  `refund_account` varchar(32) CHARACTER SET utf8 COLLATE utf8_bin DEFAULT NULL COMMENT '退款资金来源 REFUND_SOURCE_RECHARGE_FUNDS 可用余额退款/基本账户 REFUND_SOURCE_UNSETTLED_FUNDS 未结算资金退款',
  `refund_fee` varchar(32) CHARACTER SET utf8 COLLATE utf8_bin DEFAULT '0' COMMENT '申请退款金额 退款总金额,单位为分',
  `refund_id` varchar(32) DEFAULT '' COMMENT '微信退款单号',
  `refund_recv_accout` varchar(32) DEFAULT '' COMMENT '退款入账账户 取当前退款单的退款入账方 1）退回银行卡： {银行名称}{卡类型}{卡尾号} 2）退回支付用户零钱: 支付用户零钱 3）退还商户: 商户基本账户 商户结算银行账户 4）退回支付用户零钱通: 支付用户零钱通',
  `refund_request_source` varchar(32) CHARACTER SET utf8 COLLATE utf8_bin DEFAULT '' COMMENT '退款状态 SUCCESS-退款成功 CHANGE-退款异常 REFUNDCLOSE—退款关闭',
  `refund_status` varchar(32) DEFAULT '' COMMENT '退款发起来源 API接口VENDOR_PLATFORM商户平台',
  `settlement_refund_fee` varchar(32) CHARACTER SET utf8 COLLATE utf8_bin DEFAULT '' COMMENT '退款金额 退款金额=申请退款金额-非充值代金券退款金额，退款金额<=申请退款金额',
  `settlement_total_fee` varchar(32) DEFAULT '' COMMENT '应结订单金额 当该订单有使用非充值券时，返回此字段。应结订单金额=订单金额-非充值代金券金额，应结订单金额<=订单金额',
  `success_time` varchar(32) DEFAULT '' COMMENT '退款成功时间 资金退款至用户帐号的时间，格式2017-12-15 09:46:01',
  `total_fee` varchar(32) DEFAULT '' COMMENT '订单金额 订单总金额，单位为分，只能为整数',
  `transaction_id` varchar(32) DEFAULT NULL COMMENT '微信订单号',
  `timestamp` int(11) NOT NULL DEFAULT '0' COMMENT '时间戳',
  `updatedAt` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `createdAt` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `type_index` (`mch_id`),
  KEY `timestamp_index` (`timestamp`),
  KEY `appid_index` (`appid`),
  KEY `openid_index` (`refund_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='微信-支付日志'
*/
